@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: Patch.py 11185 2018-08-04 18:13:19Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Date: 2018-08-05 02:13:19 +0800 (Sun, 05 Aug 2018) $
+# $Revision: 11185 $
 #
 # Contributors:
 #  Bear
@@ -185,6 +185,11 @@ def attachURLs(settings, urlpatterns):
     @param urlpatterns urlpatterns in urls.py.
     """
     from django.conf.urls import url, include, patterns
+    from des import urls as des_urls
+
+    urlpatterns += patterns('',
+        url(r'^django-des/', include(des_urls)),
+    )
 
     if settings.DEBUG == False and settings.SERVER_MODE == settings.DEVELOPMENT:
         urlpatterns += patterns('',
