@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Service.py 11270 2018-11-29 01:56:59Z Kevin $
+# $Id: Service.py 11299 2018-12-06 09:24:18Z Kevin $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Kevin $ (last)
-# $Date: 2018-11-29 10:56:59 +0900 (週四, 29 十一月 2018) $
-# $Revision: 11270 $
+# $Date: 2018-12-06 17:24:18 +0800 (Thu, 06 Dec 2018) $
+# $Revision: 11299 $
 
 import os
 import httplib2
@@ -30,11 +30,8 @@ try:
 except NameError:
     FileNotFoundError = IOError
 
-
-CLOUD_STORAGE_GOOGLE_SECRET = settings.CLOUD_STORAGE_GOOGLE_SECRET
-CLOUD_STORAGE_GOOGLE_SCOPE = settings.CLOUD_STORAGE_GOOGLE_SCOPE
-CLOUD_STORAGE_GOOGLE_APP_NAME = settings.CLOUD_STORAGE_GOOGLE_APP_NAME
-
+IUNO_CLOUD_STORAGE_GOOGLE_CREDENTIAL = \
+    settings.IUNO_CLOUD_STORAGE_GOOGLE_CREDENTIAL
 
 class ServiceSingleton:
     __single = None
@@ -44,12 +41,13 @@ class ServiceSingleton:
             raise ServiceSingleton.__single
         else:
             credentials = self.getCredentials(
-                CLOUD_STORAGE_GOOGLE_SECRET,
-                CLOUD_STORAGE_GOOGLE_SCOPE,
-                CLOUD_STORAGE_GOOGLE_APP_NAME
-            )
+                IUNO_CLOUD_STORAGE_GOOGLE_CREDENTIAL)
+
             self.service = discovery.build(
-                "drive", "v3", http=credentials.authorize(httplib2.Http()))
+                "drive", "v3",
+                http=credentials.authorize(httplib2.Http()),
+                cache_discovery=False)
+
         ServiceSingleton.__single = self
 
     @staticmethod
@@ -58,37 +56,34 @@ class ServiceSingleton:
             ServiceSingleton.__single = ServiceSingleton()
         return ServiceSingleton.__single
 
-    def getCredentials(self, clientSecretFile=None, scope=None,
-                       appName=None, flags=None):
-        # get or create .credentials in app dir
-        credentialDir = os.path.join(settings.BASE_DIR, ".credentials")
-        if not os.path.exists(credentialDir):
-            os.makedirs(credentialDir)
-
-        # get credential
-        credentialPath = os.path.join(credentialDir,
-                                      "drive-python-quickstart.json")
+    def getCredentials(self, credentialPath):
         store = Storage(credentialPath)
         credentials = store.get()
 
-        # create credential if not exist
         if not credentials or credentials.invalid:
-            if all(param is not None for param in (
-                    clientSecretFile, scope, appName)):
-                flow = client.flow_from_clientsecrets(
-                    clientSecretFile, scope)
-                flow.user_agent = appName
-                if flags:
-                    credentials = tools.run_flow(flow, store, flags)
-                else:
-                    credentials = tools.run_flow(flow, store)
-            else:
-                raise ValueError("'clientSecretFile', 'scope', 'appName'"
-                                 " are required for creating credentials.")
+            raise ValueError("Not a valid credentials file.")
 
         return credentials
 
-service = ServiceSingleton.getSingleton().service
+    @staticmethod
+    def createCredentials(clientSecretPath, credentialPath,
+                          scope, appName, flags=None):
+        os.makedirs(os.path.dirname(credentialPath), exist_ok=True)
+
+        store = Storage(credentialPath)
+        flow = client.flow_from_clientsecrets(
+            clientSecretPath, scope)
+        flow.user_agent = appName
+
+        import sys
+        del sys.argv[1:]
+
+        if flags:
+            credentials = tools.run_flow(flow, store, flags)
+        else:
+            credentials = tools.run_flow(flow, store)
+
+        return credentials
 
 
 def handleHttpError(error):
@@ -108,6 +103,7 @@ def _getFileByID(fileId, fields=()):
     """
     try:
         # find the file with this id
+        service = ServiceSingleton.getSingleton().service
         return service.files().get(
             fileId=fileId, fields=", ".join(fields)).execute()
     except HttpError as e:
@@ -145,6 +141,7 @@ def _getFileByPath(path, fields=()):
     filename = path.split("/")
 
     # find all the files with this name
+    service = ServiceSingleton.getSingleton().service
     files = service.files().list(
         q="name='{}'".format(filename[-1]),
         fields="files({})".format(", ".join(fields))).execute()["files"]
@@ -211,6 +208,8 @@ def getFiles(key, type=BY_ID, fields=None):
     if fields is not None:
         _fields.extend(fields)
 
+    service = ServiceSingleton.getSingleton().service
+
     # Query all the files
     files = []
     page_token = None
