@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11319 2018-12-20 12:15:17Z Lavender $
+# $Id: __init__.py 11326 2019-01-08 18:50:45Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-12-20 21:15:17 +0900 (週四, 20 十二月 2018) $
-# $Revision: 11319 $
+# $Date: 2019-01-09 02:50:45 +0800 (??, 09 ?? 2019) $
+# $Revision: 11326 $
 
 import os
 import sys
@@ -804,7 +804,8 @@ def buildAPIForm(submission, request, apiName, extra={}):
             
             "GoodsAmount": int(total),
             "CollectionAmount": int(total),
-            "GoodsName": itemName.replace("#", ' ').decode('utf8'),
+            "GoodsName": itemName.replace(
+                "#", ' ').replace("(", '').replace(")", '').decode('utf8'),
             
             # 必須 len(SendName) <= 10 個字元 
             "SenderName": shopName,
