@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11221 2018-09-02 04:41:14Z Lavender $
+# $Id: __init__.py 11314 2018-12-14 05:31:25Z Kevin $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-09-02 13:41:14 +0900 (週日, 02 九月 2018) $
-# $Revision: 11221 $
+# $Author: Kevin $ (last)
+# $Date: 2018-12-14 13:31:25 +0800 (??, 14 ??? 2018) $
+# $Revision: 11314 $
 
 import os
 
@@ -50,4 +50,9 @@ BACKUP_FILE_DIR = os.path.join(
     STATIC_DIR, BACKUP_DIR_NAME)
 
 if not os.path.isdir(BACKUP_FILE_DIR):
-    os.mkdir(BACKUP_FILE_DIR)
\ No newline at end of file
+    os.mkdir(BACKUP_FILE_DIR)
+
+import six
+
+def toBytes(s):
+    return s if six.PY2 else s.encode()
