@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11314 2018-12-14 05:31:25Z Kevin $
+# $Id: admin.py 11328 2019-01-09 14:12:55Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Kevin $
-# $Date: 2018-12-14 14:31:25 +0900 (週五, 14 十二月 2018) $
-# $Revision: 11314 $
+# $Author: Lavender $
+# $Date: 2019-01-09 22:12:55 +0800 (??, 09 ?? 2019) $
+# $Revision: 11328 $
 
 import os
 import datetime
@@ -163,32 +163,33 @@ def checkVersion(model):
     return conflictNodeList
 
 def loginCheck(sender, user, request, **kwargs):
-    def createMessage(ele, model):
-        node = ele[0]
-        version = ele[1]
+    if user.is_superuser:
+        def createMessage(ele, model):
+            node = ele[0]
+            version = ele[1]
 
-        info = model._meta.app_label, model._meta.model_name
-        url = reverse('admin:%s_%s_change' % info, args=[node.id,])
+            info = model._meta.app_label, model._meta.model_name
+            url = reverse('admin:%s_%s_change' % info, args=[node.id,])
 
-        msg = _("Version %(version)d "
-                "conflict Version %(preVersion)d !!: "
-                "<a href='%(url)s'>%(path)s</a>") % {
-                'version': version.number, 
-                'preVersion': version.preVersion.number,
-                'url': url,
-                'path': node.path,
-            }
-        return mark_safe(msg)
+            msg = _("Version %(version)d "
+                    "conflict Version %(preVersion)d !!: "
+                    "<a href='%(url)s'>%(path)s</a>") % {
+                    'version': version.number, 
+                    'preVersion': version.preVersion.number,
+                    'url': url,
+                    'path': node.path,
+                }
+            return mark_safe(msg)
 
-    conflictNodeList = checkVersion(Static)
-    for ele in conflictNodeList:
-        msg = createMessage(ele, Static)
-        messages.warning(request, msg)
+        conflictNodeList = checkVersion(Static)
+        for ele in conflictNodeList:
+            msg = createMessage(ele, Static)
+            messages.warning(request, msg)
 
-    conflictNodeList = checkVersion(Template)
-    for ele in conflictNodeList:
-        msg = createMessage(ele, Template)
-        messages.warning(request, msg)
+        conflictNodeList = checkVersion(Template)
+        for ele in conflictNodeList:
+            msg = createMessage(ele, Template)
+            messages.warning(request, msg)
 
 user_logged_in.connect(loginCheck)
 
