@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: clean_version.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: clean_version.py 11331 2019-01-12 16:18:05Z Kevin $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Author: Kevin $
+# $Date: 2019-01-13 00:18:05 +0800 (??, 13 ?? 2019) $
+# $Revision: 11331 $
 
 import os
 import shutil
@@ -34,4 +34,4 @@ class Command(BaseCommand):
 
         if not os.path.isdir(BACKUP_FILE_DIR):
             os.mkdir(BACKUP_FILE_DIR)
-        print "Successfully."
\ No newline at end of file
+        print("Successfully.")
\ No newline at end of file
